#
# CHMPX
#
# Copyright 2014 Yahoo Japan corporation.
#
# CHMPX is inprocess data exchange by MQ with consistent hashing.
# CHMPX is made for the purpose of the construction of
# original messaging system and the offer of the client
# library.
# CHMPX transfers messages between the client and the server/
# slave. CHMPX based servers are dispersed by consistent
# hashing and are automatically laid out. As a result, it
# provides a high performance, a high scalability.
#
# For the full copyright and license information, please view
# the license file that was distributed with this source code.
#
# AUTHOR:   Takeshi Nakatani
# CREATE:   Fri 17 Jul 2016
# REVISION:
#

#
# Local macros/define
#
%if %{undefined package_revision}
%global package_revision 1
%endif

%if %{undefined make_build}
%global make_build %{__make} %{?_smp_mflags}
%endif

%if %{undefined autosetup}
%global autosetup %setup -q
%endif

%global gittag v1.0.103

%if %{undefined make_check}
%global make_check 1
%endif

%if %{undefined not_run_autogen}
%global run_autogen ./autogen.sh
%else
%global run_autogen echo "skip autogen.sh"
%endif

#
# main package
#
Summary: Consistent Hashing Mq inProcess data eXchange
Name: chmpx
Version: 1.0.103
Release: %{package_revision}%{?dist}
License: MIT
Group: Applications/Communications
URL: https://github.com/yahoojapan/chmpx
Source0: https://github.com/yahoojapan/chmpx/archive/%{gittag}/%{name}-%{version}.tar.gz
Requires: k2hash%{?_isa} >= 1.0.91, libfullock%{?_isa} >= 1.0.55, nss-tools
%if 0%{?rhel} == 6
BuildRequires: git-core gcc-c++ make libtool k2hash-devel >= 1.0.91, libfullock-devel >= 1.0.55, libyaml-devel, nss-devel
%else
BuildRequires: systemd git-core gcc-c++ make libtool k2hash-devel >= 1.0.91, libfullock-devel >= 1.0.55, libyaml-devel, nss-devel
%endif

%description
CHMPX is Consistent Hashing Mq inProcess data eXchange system, and
libraries for clients by Yahoo! JAPAN.
CHMPX is made for the purpose of the construction of original messaging
system and the offer of the client library. CHMPX transfers messages
between the client and the server/slave. CHMPX based servers are dis-
persed by consistent hashing and are automatically laid out. As a
result, it provides a high performance, a high scalability.

CHMPX is following specifications:
- Build up cluster with uniq name by some servers.
- Layouts servers in cluster by consistent hashing.
- Supports interprocess communication across the servers.
- Supports synchronous/asynchronous communication.
- Supports communicating messages in the target specified(HASH).
- Supports plugin Hashing function for target messaging.(k2hash)
- Supports communicating messages in the random.
- Supports SSL communication.
- The message communication possible bypass.
- No message lost during communication failure.
- Broadcast a message communication possible.
- Provision of high-level library for clients.
- Supports multi-thread/process for client programs.

%prep
%autosetup -n %{name}-%{version}

%build
%run_autogen
%configure --disable-static --with-nss
%make_build

%install
%make_install
find %{buildroot} -name '*.la' -exec rm -f {} ';'
%if 0%{?rhel} != 6
install -D -m 644 buildutils/chmpx.service %{buildroot}/lib/systemd/system/chmpx.service
install -D -m 755 buildutils/chmpx-service-helper %{buildroot}/usr/libexec/chmpx-service-helper
install -D -m 644 buildutils/chmpx-service-helper.conf %{buildroot}/etc/antpickax/chmpx-service-helper.conf
install -D -m 644 buildutils/chmpx.ini.example %{buildroot}/etc/antpickax/chmpx.ini.example
%endif
mkdir -p %{buildroot}/var/lib/antpickax
mkdir -p %{buildroot}/var/run/antpickax

%if %{make_check}
%check
%{__make} check
%endif

%if %{defined ldconfig_scriptlets}
%ldconfig_scriptlets
%else
%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%endif

%if 0%{?rhel} == 6
%clean
rm -rf %{buildroot}
%endif

%files
%if 0%{?rhel} == 6
%doc COPYING
%defattr(-,root,root)
%else
%license COPYING
%endif
%doc README AUTHORS ChangeLog
%{_libdir}/*.so.1*
%{_mandir}/man1/*
%{_bindir}/*
%if 0%{?rhel} != 6
/lib/systemd/system/chmpx.service
/usr/libexec/chmpx-service-helper
/etc/antpickax/*
%endif
%dir %attr(0777,root,root) /var/lib/antpickax
%dir %attr(0777,root,root) /var/run/antpickax

%if 0%{?rhel} != 6
%preun
%systemd_preun chmpx.service
%endif

#
# devel package
#
%package devel
Summary: Consistent Hashing Mq inProcess data eXchange (development)
Requires: %{name}%{?_isa} = %{version}-%{release}, k2hash-devel%{?_isa} >= 1.0.91, libfullock-devel%{?_isa} >= 1.0.55, libyaml-devel, nss-devel

%description devel
Development package for building with chmpx shared library.
This package has header files and symbols for it.

%files devel
%if 0%{?rhel} == 6
%defattr(-,root,root)
%endif
%doc README AUTHORS ChangeLog
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Fri Oct 27 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.103-1
- Changed support OS (fedora and ubuntu) and updated tool - #132

* Fri Sep 29 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.102
- Changed handling certificates for NSS and updated dependencies - #130

* Wed Aug 30 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.101
- Updated tool scripts and support OSs - #128
- Fixed .gitignore to exclude APKBUILD.templ - #127

* Wed Jul 19 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.100
- Fixed a bug in script for systemd - #125

* Thu May 11 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.99
- Fixed bugs about connecting with SSL by gnuTLS - #123

* Tue Feb 28 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.98
- Updated building/packaging logic for ALPINE - #121

* Thu Feb 09 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.97
- Changed CI process flow/OSs and added Alpine OS - #119
- Updated header and footer in comment lines - #118
- Updated issue/pullrequest templates - #116
- Fixed a bug in test.sh - #115
- Added ShellCheck processing and reviewed cppcheck - #114
- Eliminated unnecessary copies in build_helper.sh - #113
- Updated docker/login-action from v1 to v2 - #112
- Shared Docker image build logic with other products - #111
- Fixed ostypevars.sh script - #110
- Updated github actions process and support os, and fixed bugs - #109
- Updated scripts for adding grep params and replacing which to command - #108
- Updated common build scripts - #107
- Updated Antpickax common scripts and tools under the buildutils directory - #106
- Fixed errors reported by cppcheck 2.9 - #105
- Fixed packaging process and files for debian/ubuntu - #104
- Enabled external customization of configure.ac and fixed for building - #103

* Wed Sep 08 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.96
- Fixed a bug that a case of registered multi-FQDNs in DNS - #101

* Fri Aug 27 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.95
- Fixed Dockerfile template for calling ldconfig - #99

* Fri Aug 27 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.94
- Fixed docker image build for ubuntu - #97

* Tue Aug 17 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.93
- Added docker build and push in Github Actions - #95
- Functional improvements and bug fixes - #94

* Fri Feb 05 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.92
- Fixed a bug in chmpx-service-helper - #92

* Thu Feb 04 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.91
- Fixed an issue with stopping service subprocesses - #90
- Bypass a specific version of cppcheck due to poor performance - #89

* Wed Feb 03 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.90
- Enhanced confirmation of wait process for chmpx.service - #87

* Tue Jan 26 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.89
- Updated files for systemd service - #84

* Thu Dec 17 2020 Takeshi Nakatani <ggtakec@gmail.com> 1.0.88
- Added dh-systemd pakacge for building a package - #81

* Wed Dec 16 2020 Takeshi Nakatani <ggtakec@gmail.com> 1.0.87
- Added systemd service files to package - #79
- Fixed centos8 build and removed centos6 build - #78

* Tue Nov 24 2020 Takeshi Nakatani <ggtakec@gmail.com> 1.0.86
- Fixed a error by cppcheck 2.2 - #76

* Tue Nov 17 2020 Takeshi Nakatani <ggtakec@gmail.com> 1.0.85
- Switched Travis CI to Github actions and extended supported OS - #74
- Fixed bugs detected by cppcheck - #73

* Thu Oct 29 2020 Takeshi Nakatani <ggtakec@gmail.com> 1.0.84
- Enhanced inspection for hostnames that cannot be resolved - #71

* Mon Aug 31 2020 Takeshi Nakatani <ggtakec@gmail.com> 1.0.83
- Reverted and fixed again about the shared lock - #68

* Wed Aug 26 2020 Takeshi Nakatani <ggtakec@gmail.com> 1.0.82
- Fixed chmpxlinetool bug for nodes with different resolv - #66
- Fixed slave node startup failure when resolv is different - #65
- Fixed merge failure at discarding internal data of DOWN snode - #64

* Tue Aug 18 2020 Takeshi Nakatani <ggtakec@gmail.com> 1.0.81
- Fixed a bug of dynamic addition/deletion of server nodes - #62

* Fri Aug 14 2020 Takeshi Nakatani <ggtakec@gmail.com> 1.0.80
- Fixed a bug of adding server node when updating conf - #60

* Wed Aug 12 2020 Takeshi Nakatani <ggtakec@gmail.com> 1.0.79
- Enhanced logic for initial connection of server nodes - #58

* Thu Aug 06 2020 Takeshi Nakatani <ggtakec@gmail.com> 1.0.78
- Fixed some warning in travis.yml - #56
- Fixed a parameter and display host format - #55
- Fixed the process in adding/removing nodes to/from a running cluster - #54
- Changed the file descriptor etc. used in the shared lock - #53

* Thu Jul 30 2020 Takeshi Nakatani <ggtakec@gmail.com> 1.0.77
- Order of server is by CUSTOM_ID_SEED when CHMPXIDTYPE=CUSTOM - #51

* Tue Jul 21 2020 Takeshi Nakatani <ggtakec@gmail.com> 1.0.76
- Delete server nodes when updating the configuration - #49
- Allowed unspecified CUSTOM_ID_SEED of slave node - #48
- Supported regular expression to CUK in slave setting - #47

* Tue Jun 09 2020 Takeshi Nakatani <ggtakec@gmail.com> 1.0.75
- Added checking resolv for hostname - #45

* Fri Apr 03 2020 Takeshi Nakatani <ggtakec@gmail.com> 1.0.74
- Fixed bugs about reverse peer and etc - #43
- Changed to not check expiration date in merge process - #42
- Fixed code for cppcheck 1.90 - #41

* Tue Dec 24 2019 Takeshi Nakatani <ggtakec@gmail.com> 1.0.73
- Fixed a bug about complete auto merging - #38

* Fri Dec 20 2019 Takeshi Nakatani <ggtakec@gmail.com> 1.0.72
- Fixed a bug and updated version of dependency packages - #36

* Fri Dec 20 2019 Takeshi Nakatani <ggtakec@gmail.com> 1.0.71
- Enhanced feature about IPv6 and NAT support - #34

* Mon Dec 02 2019 Takeshi Nakatani <ggtakec@gmail.com> 1.0.70
- Host matching improvements and fixes bugs - #32
- Enhanced node discovery of hostnames and IP addresses - #31

* Mon Mar 25 2019 Takeshi Nakatani <ggtakec@gmail.com> 1.0.69
- Updated chmpxstatus man page - #28
- Added status wait mode to chmpxstatus command - #27

* Tue Mar 12 2019 Takeshi Nakatani <ggtakec@gmail.com> 1.0.68
- Fixed codes for cppcheck 1.87 - #23

* Thu Jan 17 2019 Takeshi Nakatani <ggtakec@gmail.com> 1.0.67
- Fixed misspelling, and etc - #20
- Added check using cppcheck - #19
- Reflected the spelling check result for all sources - #18

* Wed Dec 26 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.66
- Fixed build warning about comparison of pointer with integer

* Tue Dec 11 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.65
- Updated common build tool files

* Wed Dec 05 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.64
- Fixed some compile warnings and updated AUTHOR
- Changed to strict packaging and changed documents

* Wed Oct 17 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.63
- Fixed spec file and updated dependency

* Mon Jul 02 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.62
- avoid static object initialization order problem(SIOF)

* Tue Jun 26 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.61
- Fixed bugs about implementation some functions, etc

* Thu Jun 21 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.60
- Supports multiple SSL/TLS libraries and associated implementation

* Thu May 17 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.59
- Cleanup credit comments in sources and Modified etc
- Changed build logic to new for rpm/debian packaging
- Fixed filename typo from make_valiables.sh to make_variables.sh
- Fixed build error with openssl 1.1.0

* Mon Mar 26 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.58
- Update dependency on k2hash v1.0.57

* Fri Mar 23 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.57
- Improved the appearance of chmpxlinetool
- Added chmpxlinetool and changed some logic/codes, fixed bugs

* Tue Mar 13 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.56
- Fixed bugs about connecting SSL and invalid result on ctlport

* Wed Mar 07 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.55
- Fixed bugs about status and updating status flow etc

* Tue Feb 27 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.54
- Enhanced status and status flow and Fixed bugs about status

* Tue Feb 13 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.53
- Force to set SERVICE OUT/DOWN status when all server chmpx down

* Tue Mar 28 2017 Takeshi Nakatani <ggtakec@gmail.com> 1.0.52
- Updated fullock and k2hash submodule version
- Updated k2hash submodule v1.0.56
- Updated fullock submodule v1.0.24
- Added lib_version_for_link option to make_valiables.sh

* Tue Feb 14 2017 Takeshi Nakatani <ggtakec@gmail.com> 1.0.51
- Updated dependency for fixing bugs in libfullock
- Fixed error/warning for compiling and changed travis.yaml - #2

* Wed Dec 07 2016 Takeshi Nakatani <ggtakec@gmail.com> 1.0.50
- First version of open sorce on Github
